Copyright notices - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Copyright notices

Copyright notices inherit from `betty.copyright_notice.CopyrightNotice`.

## Built-in copyright notices

`betty.copyright_notice.copyright_notices.ProjectAuthor`

  Copyright lies with the project author.

`betty.copyright_notice.copyright_notices.PublicDomain`

  A work is in the public domain <https://en.wikipedia.org/wiki/Public_domain>.

## See also

- Copyright notice plugins